@@ -20,7 +20,7 @@ import logging
 import requests
 import re
 from subprocess import Popen, PIPE
-from astropy.io import ascii
+from prettytable import *
 from ferry.options import CmdHelp
 from ferry.install import Installer, FERRY_HOME
 
@@ -65,55 +65,70 @@ class CLI(object):
         return str(res.text)
 
     def _format_snapshots_query(self, json_data):
-        lines = ['UUID & Base & Date']
-
-        # Each additional row should include the actual data.
+        bases = []
+        date = []
         for uuid in json_data.keys():
-            l = uuid + '&'
-            l += json_data[uuid]['base'] + '&'
-            l += json_data[uuid]['snapshot_ts']
+            bases.append(json_data[uuid]['base'])
+            if 'snapshot_ts' in json_data[uuid]:
+                date.append(json_data[uuid]['snapshot_ts'])
+            else:
+                date.append(' ')
 
-            lines.append(l)
-
-        return ascii.read(lines, data_start=1, delimiter='&')
+        t = PrettyTable()
+        t.add_column("UUID", json_data.keys())
+        t.add_column("Base", bases)
+        t.add_column("Date", date)
+        return t.get_string(sortby="Date",
+                            border=True, 
+                            vrules=ALL, 
+                            vertical_char=' ', 
+                            junction_char=' ', 
+                            padding_width=4)
 
     def _format_table_query(self, json_data):
-        lines = ['UUID & Storage & Compute & Connectors & Status & Base & Time']
+        storage = []
+        compute = []
+        connectors = []
+        status = []
+        base = []
+        time = []
 
         # Each additional row should include the actual data.
         for uuid in json_data.keys():
-            connector_uuids = ''
-            connectors = json_data[uuid]['connectors']
-            i = 0
-            for c in connectors:
-                connector_uuids += str(c)
-                i += 1
-                if i < len(connectors):
-                    connector_uuids += ','
+            for c in json_data[uuid]['connectors']:
+                connectors.append(c)
 
-            compute_uuids = ''
-            storage_uuids = ''
             backends = json_data[uuid]['backends']
-            i = 0
             for b in backends:
-                compute_uuids += str(b['compute'])
-                storage_uuids += str(b['storage'])
-                i += 1
-                if i < len(backends):
-                    compute_uuids += ','
-                    storage_uuids += ','
+                if b['storage']:
+                    storage.append(b['storage'])
+                else:
+                    storage.append(' ')
 
-            l = uuid + '&'
-            l += storage_uuids + '&'
-            l += compute_uuids + '&'
-            l += connector_uuids + '&'
-            l += json_data[uuid]['status'] + '&'
-            l += json_data[uuid]['base'] + '&'
-            l += json_data[uuid]['ts']
+                if b['compute']:
+                    compute.append(b['compute'])
+                else:
+                    compute.append(' ')
 
-            lines.append(l)
+            status.append(json_data[uuid]['status'])
+            base.append(json_data[uuid]['base'])
+            time.append(json_data[uuid]['ts'])
 
-        return ascii.read(lines, data_start=1, delimiter='&')
+        t = PrettyTable()
+        t.add_column("UUID", json_data.keys())
+        t.add_column("Storage", storage)
+        t.add_column("Compute", compute)
+        t.add_column("Connectors", connectors)
+        t.add_column("Status", status)
+        t.add_column("Base", base)
+        t.add_column("Time", time)
+
+        return t.get_string(sortby="UUID",
+                            border=True, 
+                            vrules=ALL, 
+                            vertical_char=' ', 
+                            junction_char=' ', 
+                            padding_width=4)
 
     def _read_stacks(self, show_all=False, args=None):
         try:
@@ -132,7 +147,7 @@ class CLI(object):
 
             # Merge the replies and format.
             return self._format_table_query(dict(query_reply.items() + deployed_reply.items()))
-        except ConnectionError:
+        except requests.ConnectionError:
             logging.error("could not connect to ferry server")
             return 'could not connect to ferry server'
 
@@ -321,7 +336,8 @@ def main(argv=None):
     console = logging.StreamHandler(stream=sys.stderr)
     console.setFormatter(logging.Formatter(fmt='%(asctime)s %(message)s', 
                                            datefmt='%m/%d/%Y %I:%M:%S %p'))
-    console.setLevel(logging.ERROR)
+    # console.setLevel(logging.ERROR)
+    console.setLevel(logging.INFO)
     root_logger = logging.getLogger()
     root_logger.addHandler(console)
     root_logger.setLevel(logging.DEBUG)
